import { BaseContentBlock } from "notion-types";
import { Actions, GatsbyCache, Reporter } from "gatsby";
import { CustomImageBlock } from "../../types";
export interface BlockProcessorContext {
    actions: Actions;
    getCache: (this: void, id: string) => GatsbyCache;
    createNodeId: (this: void, input: string) => string;
    reporter: Reporter;
    cache: GatsbyCache;
}
export interface ProcessBlockResult {
    thumbnail?: string | null;
    plainText?: string;
    updatedBlock?: BaseContentBlock;
    tableOfContents?: {
        type: string;
        hash: string;
        title: string;
    }[];
}
export declare abstract class BlockProcessor {
    protected context: BlockProcessorContext;
    constructor(context: BlockProcessorContext);
    abstract canProcess(block: BaseContentBlock): boolean;
    abstract process(block: BaseContentBlock): Promise<ProcessBlockResult>;
    protected extractPlainText(block: BaseContentBlock): string | null;
    protected isTextContentBlock(block: BaseContentBlock): block is BaseContentBlock & {
        [key in "paragraph" | "heading_1" | "heading_2" | "heading_3" | "quote" | "bulleted_list_item" | "numbered_list_item" | "callout" | "code" | "toggle" | "to_do" | "bookmark" | "table_of_contents" | "breadcrumb" | "divider" | "embed"]?: {
            rich_text: {
                plain_text: string;
            }[];
        };
    };
    protected isImageBlock(block: BaseContentBlock): block is CustomImageBlock;
}
